# Class: example


usage example and description

URI: [http://w3id.org/biolink/biolinkml/meta/Example](http://w3id.org/biolink/biolinkml/meta/Example)

![img](images/Example.png)
## Inheritance

## Children

## Used by

 *  **[Element](Element.md)** *[examples](examples.md)<sub>opt</sub>*  **[[Example](Example.md)]**
## Fields

 * [value](value.md)<sub>opt</sub>
    * range: [String](String.md)
 * [example.description](value_description.md)<sub>opt</sub>
    * range: [String](String.md)
